@@ -33,12 +33,12 @@ module wt_module
 
   public wt_Initial
 
-  public x_LON, x_LON_WEIGHT
-  public y_LAT, y_LAT_WEIGHT
-  public z_RAD, z_RAD_WEIGHT
+  public x_Lon, x_Lon_Weight
+  public y_Lat, y_Lat_Weight
+  public z_Rad, z_Rad_Weight
   public l_nm, nm_l
-  public xyz_LON, xyz_LAT, xyz_RAD
-  public wz_RAD
+  public xyz_Lon, xyz_Lat, xyz_Rad
+  public wz_Rad
 
   public w_xy, xy_w
   public at_Dr_at, t_Dr_t, az_at, at_az
@@ -59,7 +59,7 @@ module wt_module
   public wt_RadRot_xyz_xyz, wt_RadRotRot_xyz_xyz_xyz
   public wt_Potential2vector
   public wt_VGradV
-  public wtBoundaries, wt_TorBoundaries, wz_LaplaPol2Pol_wz
+  public wt_Boundaries, wt_TorBoundaries, wz_LaplaPol2Pol_wz
   public wt_TormagBoundaries, wt_PolmagBoundaries
 
   integer            :: im=64, jm=32, km=16  ! ʻ(, , ư)
@@ -100,6 +100,7 @@ module wt_module
 
      wz_Rad = spread(z_Rad,1,(nm+1)*(nm+1))
 
+     z_Rad_Weight = z_Rad_Weight * z_Rad**2       ! r^2 dr ʬŤ
    end subroutine wt_initial
 
   !--------------- Ѵ -----------------
@@ -161,7 +162,7 @@ module wt_module
 
     end function wt_DRad_wt
 
-    function wt_DivRad_wt(wt)    ! ưȯʬ 
+    function wt_DivRad_wt(wt)    ! ȯưʬ 
                                  ! 1/r^2 /r r^2 = /r + 2/r 
       real(8), dimension((nm+1)*(nm+1),0:lm), intent(in) :: wt
       real(8), dimension((nm+1)*(nm+1),0:lm)             :: wt_DivRad_wt
@@ -170,7 +171,7 @@ module wt_module
 
     end function wt_DivRad_wt
 
-    function wt_RotRad_wt(wt)    ! ưȯʬ 
+    function wt_RotRad_wt(wt)    ! žưʬ 
                                  ! 1/r /r r = /r + 1/r 
       real(8), dimension((nm+1)*(nm+1),0:lm), intent(in) :: wt
       real(8), dimension((nm+1)*(nm+1),0:lm)             :: wt_RotRad_wt
@@ -270,7 +271,7 @@ module wt_module
       xy_IntRad_xyz = 0.0d0
       do k=0,km
          xy_IntRad_xyz(:,:) = xy_IntRad_xyz(:,:) &
-                       + xyz(:,:,k) * z_Rad_Weight(k)
+                       + xyz(:,:,k) * z_Rad_Weight(k) 
       enddo
     end function xy_IntRad_xyz
 
@@ -318,7 +319,7 @@ module wt_module
 
     function IntLonLatRad_xyz(xyz) ! ٷư()ʬ
       real(8), dimension(im,jm,0:km), intent(in) :: xyz    ! 3 ʻǡ
-      real(8)                     :: IntLonLatRad_xyz      ! 
+      real(8)                     :: IntLonLatRad_xyz      ! ʬ
       integer :: i, j, k
 
       IntLonLatRad_xyz = 0
@@ -412,14 +413,14 @@ module wt_module
                     + sin(xyz_Lat)*xyz_wt(wt_Drad_wt(wt))
     end function xyz_KGrad_wt
 
-    function wt_L2_wt(wt)    ! L2  = -ʿץ饷 
+    function wt_L2_wt(wt)    ! L2 黻 = -ʿץ饷 
       real(8), dimension((nm+1)*(nm+1),0:lm), intent(in) :: wt
       real(8), dimension((nm+1)*(nm+1),0:lm)             :: wt_L2_wt
 
       wt_L2_wt = -wa_Lapla_wa(wt)
     end function wt_L2_wt
 
-    function wt_L2Inv_wt(wt)    ! L2 Ǥε = -տʿץ饷 
+    function wt_L2Inv_wt(wt)    ! L2 黻Ҥε = -տʿץ饷 
       real(8), dimension((nm+1)*(nm+1),0:lm), intent(in) :: wt
       real(8), dimension((nm+1)*(nm+1),0:lm)             :: wt_L2Inv_wt
 
@@ -511,7 +512,7 @@ module wt_module
 
   !---------------  -----------------
 
-    subroutine wtBoundaries(wt,values,cond)   ! ǥꥯ, Υޥ
+    subroutine wt_Boundaries(wt,values,cond)   ! ǥꥯ, Υޥ
       ! Chebyshev ֤ǤζŬ
 
       real(8), dimension((nm+1)*(nm+1),0:lm),intent(inout)      :: wt
@@ -562,10 +563,10 @@ module wt_module
             call at_boundaries_DD(wt)
          endif
       case default
-         call msgdmp('E','wtBoundaries','B.C. not supported')
+         call msgdmp('E','wt_Boundaries','B.C. not supported')
       end select
 
-    end subroutine wtBoundaries
+    end subroutine wt_Boundaries
 
     subroutine wt_TorBoundaries(wt_TORPOT,cond) ! ȥݥƥ󥷥붭
       ! Chebyshev ֤ǤζŬ
@@ -765,7 +766,7 @@ module wt_module
       ! ¦
       !    wt_psi = 0       at the inner boundary
       ! 
-      ! wtBoundaries бǽ, ΤӺƤ
+      ! wt_Boundaries бǽ, ΤӺƤ
 
       real(8), dimension((nm+1)*(nm+1),0:lm),intent(inout)   :: wt_TOR
               ! ŬѤǡ. 줿֤ͤ. 
@@ -812,7 +813,7 @@ module wt_module
 
     end subroutine wt_TormagBoundaries
 
-    subroutine wt_PolmagBoundaries(wt_POL) ! ȥݥƥ󥷥붭
+    subroutine wt_PolmagBoundaries(wt_POL) ! ݥݥƥ󥷥붭
       ! Chebyshev ֤ǤζŬ
       ! ݥݥƥ󥷥 \psi ζ(ŵƳ)
       ! ¦
